@@ -6,7 +6,6 @@ a supervisor for multiple uWSGI instances
 
 */
 #include "uwsgi.h"
-#include <glob.h>
 
 
 extern struct uwsgi_server uwsgi;
@@ -186,8 +185,24 @@ void uwsgi_imperial_monitor_directory(struct uwsgi_emperor_scanner *ues) {
 
 	while (c_ui) {
 		if (c_ui->scanner == ues) {
-			if (stat(c_ui->name, &st)) {
-				emperor_stop(c_ui);
+			if (c_ui->zerg) {
+				char *colon = strrchr(c_ui->name, ':');
+				if (!colon) {
+					emperor_stop(c_ui);
+				}
+				else {
+					char *filename = uwsgi_calloc(0xff);
+					memcpy(filename, c_ui->name, colon - c_ui->name);
+					if (stat(filename, &st)) {
+						emperor_stop(c_ui);
+					}
+					free(filename);
+				}
+			}
+			else {
+                                if (stat(c_ui->name, &st)) {
+                                       	emperor_stop(c_ui);
+                                }
 			}
 		}
 		c_ui = c_ui->ui_next;
@@ -246,9 +261,25 @@ void uwsgi_imperial_monitor_glob(struct uwsgi_emperor_scanner *ues) {
 
 	while (c_ui) {
 		if (c_ui->scanner == ues) {
-			if (stat(c_ui->name, &st)) {
-				emperor_stop(c_ui);
-			}
+			if (c_ui->zerg) {
+                                char *colon = strrchr(c_ui->name, ':');
+                                if (!colon) {
+                                        emperor_stop(c_ui);
+                                }
+                                else {
+                                        char *filename = uwsgi_calloc(0xff);
+                                        memcpy(filename, c_ui->name, colon - c_ui->name);
+                                        if (stat(filename, &st)) {
+                                                emperor_stop(c_ui);
+                                        }
+                                        free(filename);
+                                }
+                        }
+                        else {
+                                if (stat(c_ui->name, &st)) { 
+                                        emperor_stop(c_ui);
+                                }       
+                        }
 		}
 		c_ui = c_ui->ui_next;
 	}
@@ -549,6 +580,10 @@ void emperor_add(struct uwsgi_emperor_scanner *ues, char *name, time_t born, cha
 		}
 	}
 
+	if (n_ui->zerg) {
+		uwsgi.emperor_broodlord_num++;
+	}
+
 	// TODO pre-start hook
 
 	// a new uWSGI instance will start 
@@ -602,6 +637,16 @@ void emperor_add(struct uwsgi_emperor_scanner *ues, char *name, time_t born, cha
 		}
 		free(uef);
 
+		// add UWSGI_BROODLORD_NUM
+		if (n_ui->zerg) {
+			uef = uwsgi_num2str(uwsgi.emperor_broodlord_num);
+			if (setenv("UWSGI_BROODLORD_NUM", uef, 1)) {
+                        	uwsgi_error("setenv()");
+                        	exit(1);
+                	}
+                	free(uef);
+		}
+
 		if (n_ui->use_config) {
 			uef = uwsgi_num2str(n_ui->pipe_config[1]);
 			if (setenv("UWSGI_EMPEROR_FD_CONFIG", uef, 1)) {
@@ -709,7 +754,7 @@ void emperor_add(struct uwsgi_emperor_scanner *ues, char *name, time_t born, cha
 			exit(1);
 		}
 		if (stdin_fd != 0) {
-			if (dup2(stdin_fd, 0)) {
+			if (dup2(stdin_fd, 0) < 0) {
 				uwsgi_error("dup2()");
 				exit(1);
 			}
@@ -1023,7 +1068,7 @@ void emperor_loop() {
 					else if (byte == 30 && uwsgi.emperor_broodlord > 0 && uwsgi.emperor_broodlord_count < uwsgi.emperor_broodlord) {
 						uwsgi_log("[emperor] going in broodlord mode: launching zergs for %s\n", ui_current->name);
 						char *zerg_name = uwsgi_concat3(ui_current->name, ":", "zerg");
-						emperor_add(NULL, zerg_name, uwsgi_now(), NULL, 0, ui_current->uid, ui_current->gid);
+						emperor_add(ui_current->scanner, zerg_name, uwsgi_now(), NULL, 0, ui_current->uid, ui_current->gid);
 						free(zerg_name);
 					}
 				}
@@ -1324,13 +1369,21 @@ end:
 void uwsgi_emperor_start() {
 
 	if (!uwsgi.sockets && !ushared->gateways_cnt && !uwsgi.master_process) {
+		if (uwsgi.emperor_procname) {
+			uwsgi_set_processname(uwsgi.emperor_procname);
+		}
 		uwsgi_notify_ready();
 		emperor_loop();
 		// never here
 		exit(1);
 	}
 
-	uwsgi.emperor_pid = uwsgi_fork("uWSGI Emperor");
+	if (uwsgi.emperor_procname) {
+		uwsgi.emperor_pid = uwsgi_fork(uwsgi.emperor_procname);
+	}
+	else {
+		uwsgi.emperor_pid = uwsgi_fork("uWSGI Emperor");
+	}
 	if (uwsgi.emperor_pid < 0) {
 		uwsgi_error("pid()");
 		exit(1);
