@@ -97,8 +97,18 @@ pid_t spooler_start(struct uwsgi_spooler * uspool) {
 		exit(1);
 	}
 	else if (pid == 0) {
+
+		signal(SIGALRM, SIG_IGN);
+                signal(SIGHUP, SIG_IGN);
+                signal(SIGINT, end_me);
+                signal(SIGTERM, end_me);
 		// USR1 will be used to wake up the spooler
 		uwsgi_unix_signal(SIGUSR1, spooler_wakeup);
+                signal(SIGUSR2, SIG_IGN);
+                signal(SIGPIPE, SIG_IGN);
+                signal(SIGSTOP, SIG_IGN);
+                signal(SIGTSTP, SIG_IGN);
+
 		uwsgi.mywid = -1;
 		uwsgi.mypid = getpid();
 		uspool->pid = uwsgi.mypid;
