@@ -23,6 +23,9 @@ struct uwsgi_perl {
 	int no_die_catch;
 	int stacktrace_available;
 
+	char *argv_items;
+	struct uwsgi_string_list *argv_item;
+
 	// this is a pointer to the main list of interpreters (required for signals, rpc....);
         PerlInterpreter **main;
 
@@ -37,6 +40,9 @@ struct uwsgi_perl {
 
 	CV **tmp_psgix_logger;
 	CV **tmp_stream_responder;
+	
+	SV *postfork;
+	SV *atexit;
 };
 
 void init_perl_embedded_module(void);
@@ -52,3 +58,4 @@ int uwsgi_perl_obj_isa(SV *, char *);
 int init_psgi_app(struct wsgi_request *, char *, uint16_t, PerlInterpreter **);
 PerlInterpreter *uwsgi_perl_new_interpreter(void);
 int uwsgi_perl_mule(char *);
+void uwsgi_perl_run_hook(SV *);
