@@ -270,7 +270,7 @@ int uwsgi_proto_http_parser(struct wsgi_request *wsgi_req) {
 	char post_buf[8192];
 	char *post_tail = NULL;
 
-	// first round ? this memory area will be freed by async_loop
+	// first round ? 
 	if (!wsgi_req->proto_parser_buf) {
 		wsgi_req->proto_parser_buf = uwsgi_malloc(uwsgi.buffer_size);
 	}
@@ -281,12 +281,15 @@ int uwsgi_proto_http_parser(struct wsgi_request *wsgi_req) {
 			remains = UMIN(remains, 8192);
 			len = read(wsgi_req->poll.fd, post_buf, remains);
 			if (len <= 0) {
-				if (len < 0)
+				if (len < 0) {
+					free(wsgi_req->proto_parser_buf);
 					uwsgi_error("read()");
+				}
 				return -1;
 			}
 
 			if (!fwrite(post_buf, len, 1, wsgi_req->async_post)) {
+				free(wsgi_req->proto_parser_buf);
 				uwsgi_error("fwrite()");
 				return -1;
 			}
@@ -296,6 +299,7 @@ int uwsgi_proto_http_parser(struct wsgi_request *wsgi_req) {
 				return UWSGI_AGAIN;
 
 		}
+		free(wsgi_req->proto_parser_buf);
 		rewind(wsgi_req->async_post);
 		wsgi_req->body_as_file = 1;
 		return UWSGI_OK;
@@ -334,11 +338,14 @@ int uwsgi_proto_http_parser(struct wsgi_request *wsgi_req) {
 				memcpy(post_tail, ptr, remains);
 			}
 			http_parse(wsgi_req, ptr);
+			wsgi_req->uh.modifier1 = uwsgi.http_modifier1;
+			wsgi_req->uh.modifier2 = uwsgi.http_modifier2;
 			//is there a Content_Length ?
 			if (wsgi_req->post_cl > 0) {
 				wsgi_req->async_post = tmpfile();
 				if (!wsgi_req->async_post) {
 					free(wsgi_req->proto_parser_buf);
+					if (post_tail) free(post_tail);
 					uwsgi_error("tmpfile()");
 					return -1;
 				}
@@ -393,14 +400,19 @@ void uwsgi_httpize_var(char *buf, size_t len) {
 	}
 }
 
-struct uwsgi_buffer *uwsgi_to_http(struct wsgi_request *wsgi_req, char *host, uint16_t host_len) {
+struct uwsgi_buffer *uwsgi_to_http(struct wsgi_request *wsgi_req, char *host, uint16_t host_len, char *uri, uint16_t uri_len) {
 
         struct uwsgi_buffer *ub = uwsgi_buffer_new(4096);
 
         if (uwsgi_buffer_append(ub, wsgi_req->method, wsgi_req->method_len)) goto clear;
         if (uwsgi_buffer_append(ub, " ", 1)) goto clear;
 
-        if (uwsgi_buffer_append(ub, wsgi_req->uri, wsgi_req->uri_len)) goto clear;
+	if (uri_len && uri) {
+        	if (uwsgi_buffer_append(ub, uri, uri_len)) goto clear;
+	}
+	else {
+        	if (uwsgi_buffer_append(ub, wsgi_req->uri, wsgi_req->uri_len)) goto clear;
+	}
 
         if (uwsgi_buffer_append(ub, " HTTP/1.0\r\n", 11)) goto clear;
 
@@ -447,11 +459,22 @@ next:
 		if (uwsgi_buffer_append(ub, "\r\n", 2)) goto clear;
 	}
 
+	if (wsgi_req->content_type_len > 0) {
+		if (uwsgi_buffer_append(ub, "Content-Type: ", 14)) goto clear;
+		if (uwsgi_buffer_append(ub, wsgi_req->content_type, wsgi_req->content_type_len)) goto clear;
+		if (uwsgi_buffer_append(ub, "\r\n", 2)) goto clear;
+	}
+
+	if (wsgi_req->post_cl > 0) {
+		if (uwsgi_buffer_append(ub, "Content-Length: ", 16)) goto clear;
+		if (uwsgi_buffer_num64(ub, (int64_t) wsgi_req->post_cl)) goto clear;
+		if (uwsgi_buffer_append(ub, "\r\n", 2)) goto clear;
+	}
+
 	// append required headers
 	if (uwsgi_buffer_append(ub, "Connection: close\r\n", 19)) goto clear;
 	if (uwsgi_buffer_append(ub, "X-Forwarded-For: ", 17)) goto clear;
 
-
 	if (x_forwarded_for_len > 0) {
 		if (uwsgi_buffer_append(ub, x_forwarded_for, x_forwarded_for_len)) goto clear;
 		if (uwsgi_buffer_append(ub, ", ", 2)) goto clear;
